This is a live mirror of the Perl 5 development currently hosted at https://github.com/perl/perl5
t/run/locale.t: Rmv obsolete complicated idiom
[perl5.git] / util.h
diff --git a/util.h b/util.h
index 4e5b97d..08544f5 100644 (file)
--- a/util.h
+++ b/util.h
@@ -52,10 +52,13 @@ This is a synonym for (! foldEQ_locale())
 #define ibcmp(s1, s2, len)         cBOOL(! foldEQ(s1, s2, len))
 #define ibcmp_locale(s1, s2, len)  cBOOL(! foldEQ_locale(s1, s2, len))
 
-/* perl.h undefs HAS_QUAD if IV isn't 64-bit */
-#ifdef U64TYPE
-/* use a faster implementation when quads are available */
-#define PERL_DRAND48_QUAD
+/* outside the core, perl.h undefs HAS_QUAD if IV isn't 64-bit
+   We can't swap this to HAS_QUAD, because the logic here affects the type of
+   perl_drand48_t below, and that is visible outside of the core.  */
+#if defined(U64TYPE) && !defined(USING_MSVC6)
+/* use a faster implementation when quads are available,
+ * but not with VC6 on Windows */
+#    define PERL_DRAND48_QUAD
 #endif
 
 #ifdef PERL_DRAND48_QUAD